==> haskell-data-clist-0.2-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-clist
version:              0.2
visibility:           public
id:                   data-clist-0.2-1RlKV2NJJZ32cxJbQS8oFe
key:                  data-clist-0.2-1RlKV2NJJZ32cxJbQS8oFe
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  00a28e8fa2dece3f756528f939531dbf
exposed:              True
exposed-modules:      Data.CircularList Data.CircularList.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/data-clist-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/data-clist-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-clist
hs-libraries:         HSdata-clist-0.2-1RlKV2NJJZ32cxJbQS8oFe
depends:              base-4.15.1.0 deepseq-1.4.5.0
haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-clist-0.2-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-clist
version:              0.2
visibility:           public
id:                   data-clist-0.2-Lg5YLA9nM703SyReWRXA65
key:                  data-clist-0.2-Lg5YLA9nM703SyReWRXA65
license:              BSD-3-Clause
maintainer:
    Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>

author:               John Van Enk <vanenkj@gmail.com>
stability:            experimental
homepage:             https://github.com/sw17ch/data-clist
synopsis:             Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.

category:             Data Structures
abi:                  e85aa6f93b70e2e0911bce9f82ff1d7c
exposed:              True
exposed-modules:      Data.CircularList Data.CircularList.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/data-clist-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/data-clist-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-clist
hs-libraries:         HSdata-clist-0.2-Lg5YLA9nM703SyReWRXA65
depends:              base-4.15.1.0 deepseq-1.4.5.0
haddock-interfaces:   /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html:         /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
